GENRE_CODE = {
    "AAAA": "act",
    "BBBC": "various_dance",
    "BBBE": "popular_dance",
    "CCCA": "classic",
    "CCCC": "korean_classical",
    "CCCD": "popular_music",
    "EEEA": "complex",
    "EEEB": "magic",
    "GGGA": "musical"
}

GENRE_CODE_RESERVATION = {
    "AAAA": "act",
    "GGGA": "musical",
    "CCCA": "classic",
    "CCCC": "korean_classical",
    "CCCD": "popular_music",
    "BBBC": "dance",
    "BBBR": "popular_dance",
    "EEEB": "magic",
    "EEEA": "complex",
    "KID": "children",
    "OPEN": "openrun"
}


AREA_CODE = {
    "11": "seoul",
    "26": "busan",  
    "27": "daegu",
    "28": "inchon",
    "29": "gwangju",
    "30": "daejeon",
    "31": "ulsan",
    "36": "sejong",
    "41": "gyeonggi",
    "42": "gangwon",
    "43": "chungbuk",
    "44": "chungnam",
    "45": "jeonbuk",
    "46": "jeonnam",
    "47": "gyeongbuk",
    "48": "gyeongnam",
    "50": "jeju"
}
